To cite Nengo, please use:

Trevor Bekolay, James Bergstra, Eric Hunsberger, Travis DeWolf,
Terrence C Stewart, Daniel Rasmussen, Xuan Choo, Aaron Russell Voelker,
and Chris Eliasmith.
Nengo: a Python tool for building large-scale functional brain models.
Frontiers in Neuroinformatics, 2014.

A BibTeX entry for LaTeX users is

.. code:: tex

   @article{bekolay2014,
     author={Bekolay, Trevor and Bergstra, James and Hunsberger, Eric and DeWolf, Travis and Stewart, Terrence C and Rasmussen, Daniel and Choo, Xuan and Voelker, Aaron Russell and Eliasmith, Chris},
     title={Nengo: A Python tool for building large-scale functional brain models},
     journal={Frontiers in Neuroinformatics},
     volume={7},
     year={2014},
     number={48},
     doi={10.3389/fninf.2013.00048},
     issn={1662-5196},
     url={http://www.frontiersin.org/neuroinformatics/10.3389/fninf.2013.00048/abstract}
   }
